Welcome to Transcrypt's documentation!
======================================

Can't find what you're looking for?
The `on-line version of this documentation <http://sterlicht.alwaysdata.net/transcrypt.org/docs/html/>`_ is frequently updated, reflecting the newest features and troubleshooting procedures.

Table of Contents:
------------------

.. toctree::
	:numbered:
	:maxdepth: 3
	
	what_why
	installation_use
	special_facilities
	supported_constructs
	integration_javascript
	autotesting_transcrypt
	philosophy_directions
	differences_cpython
